@@ -48,7 +48,7 @@ def BoundPropertyAttribute(classMember, attribute, SA2R=None, PY2R=None):
     the basic python types of the column.  The callables SA2R, SA2PY and PY2R
     extend this function with the ability to do so.
 
-    :param classMember:  UserAttr, ModelColumn or SQLalchemy column
+    :param classMember:  UserAttr, :class:`ModelColumn` or SQLalchemy column
         attribute to introspect
     :param attribute:  The attribute value to compute
     :param SA2R:  a callable taking the SQLAlchemy column type and returning
@@ -334,7 +334,7 @@ def attrYoke(cls, col):
     This helper function returns a label from class and attribute pair.  It handles the following cases:
      - cls is a new-style python class and col is a string representing the attribute name of a UserAttr
      - cls is a new-style python class and col is a string representing the attribute name of a SqlAlchemy column
-     - cls is None and col is a ModelColumn object
+     - cls is None and col is a :class:`ModelColumn` object
     
     >>> m=ModelColumn("name",str,"First Name")
     >>> attrYoke(None,m)
@@ -421,7 +421,7 @@ def attrType(cls, col):
     This helper function returns a type from class and attribute pair.  It handles the following cases:
      - cls is a new-style python class and col is a string representing the attribute name of a UserAttr
      - cls is a new-style python class and col is a string representing the attribute name of a SqlAlchemy column
-     - cls is None and col is a ModelColumn object
+     - cls is None and col is a :class:`ModelColumn` object
     
     >>> m=ModelColumn("name",str,"First Name")
     >>> attrType(None,m)
@@ -524,16 +524,18 @@ def AttrWidgetFactory(userattr,parent=None, index=None):
 
 
 class ModelColumn:
+    """
+    :param attr:  attribute name
+    :param label:  label to display in the list header
+    :param readonly:  true if the column should not be editable even if the
+        view is editable
+    :param width:  width in pixels (?) or relative width to other columns
+    :param empty_zero:  display 0's as empty strings in display mode if true 
+    :param alignment:  preferred alignment of text in the column - 
+        options include "right", "left", "top-left" and the general form is
+        "vertical-horizontal" with the vertical part being optional
+    """
     def __init__(self, attr, type_, label=None, readonly=False, width=None, empty_zero=True, alignment=None):
-        """
-        :param attr:  attribute name
-        :param label:  label to display in the list header
-        :param readonly:  true if the column should not be editable even if the view is
-        :param width:  width in pixels (?) or relative width to other columns
-        :param empty_zero:  display 0's as empty strings in display mode if true 
-        :param alignment:  preferred alignment of text in the column
-            options include "right", "left", "top-left" and the general form is "vertical-horizontal" with the vertical part being optional
-        """
         self.attr = attr
         if label is None:
             self.label = attr.title().replace("_"," ")
@@ -773,18 +775,19 @@ def QueryTableModel(q, cols=None, include_uuid=False, ssrc=None, objectConverter
 
 class PBTableModel(QtCore.QAbstractItemModel):
     """
-    A PyQt/PySide model for objects with :class:`UserAttr`.
+    A PyQt/PySide model for objects with :class:`UserAttr`.  All parameters
+    other than columns are optional.
+
+    :param columns:  A list of columns.  These could be attribute names or
+        :class:`ModelColumn` objects.  Both methods can be used in the same
+        model instance.
+    :param query:  This could be SA Query object or a list of row objects
+    :param cls:  The class of objects in the row list.
+    :param ssrc:  A sqlalchemy sessionmaker.
+    :param objectConverter: Callable taking row objects to unique keys in the
+        application domain
     """
     def __init__(self, columns, cls=None, rows=None, query=None, ssrc=None, parent=None, readonly=True, row_manager=None, fixed_rows=False, objectConverter=None, tree_structure=None):
-        """
-        All parameters other than columns are optional.
-
-        :param columns:  A list of columns.  These could be attribute names or ModelColumn objects.  Both methods can be used in the same model instance.
-        :param query:  This could be SA Query object or a list of row objects
-        :param cls:  The class of objects in the row list.
-        :param ssrc:  A sqlalchemy sessionmaker.
-        :param objectConverter: Callable taking row objects to unique keys in the application domain
-        """
         QtCore.QAbstractItemModel.__init__(self,parent)
         self.columns = columns
         self.cls = cls
