@@ -10,6 +10,20 @@ from PySide import QtCore, QtGui
 from auth_settings import AuthSettings
 from objectforms import MapperDialog, exception_message_box
 
+def qtGetSaveFileName(parent, title, filter):
+    if QtCore.__name__.split('.')[0] == 'PySide':
+        fileName, filter = QtGui.QFileDialog.getSaveFileName(parent, title, filter=filter)
+    else:
+        fileName = QtGui.QFileDialog.getSaveFileName(parent, title, filter=filter)
+    return fileName
+
+def qtGetOpenFileName(parent, title, filter):
+    if QtCore.__name__.split('.')[0] == 'PySide':
+        fileName, filter = QtGui.QFileDialog.getOpenFileName(parent, title, filter=filter)
+    else:
+        fileName = QtGui.QFileDialog.getOpenFileName(parent, title, filter=filter)
+    return fileName
+
 class MultiAuthDialog(MapperDialog):
     def __init__(self,parent=None,init_session_maker=None,init_db=None):
         MapperDialog.__init__(self,parent)
@@ -68,12 +82,12 @@ class MultiAuthDialog(MapperDialog):
         return wid
 
     def sqlite_browse(self):
-        fileName = QtGui.QFileDialog.getOpenFileName(self,"Select Existing SQLite Database",filter="SQLite databases (*.db);;All Files (*.*)")
+        fileName = qtGetOpenFileName(self,"Select Existing SQLite Database",filter="SQLite databases (*.db);;All Files (*.*)")
         if fileName != "":
             self.sqlite_file.setText(fileName)
 
     def sqlite_initialize(self):
-        fileName = QtGui.QFileDialog.getSaveFileName(self,"New SQLite Database",filter="SQLite databases (*.db);;All Files (*.*)")
+        fileName = qtGetSaveFileName(self,"New SQLite Database",filter="SQLite databases (*.db);;All Files (*.*)")
         if fileName != "":
             self.init_db("sqlite:///" + fileName)
             self.sqlite_file.setText(fileName)
