@@ -2,7 +2,7 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
@@ -28,6 +28,27 @@ class InputYoke(object):
     
     def __init__(self,mapper):
         self.mapper = mapper
+        self.knowable_dirty = False
+        self.is_dirty = False
+
+    def mark_dirty(self):
+        self.is_dirty = True
+
+    def _save_dirty_blowout(self):
+        # In this function, we check a number of conditions that need to be met
+        # to make it sensible to save from the gui widget to the object.
+        if hasattr(self, "attr") and attrReadonly(self.mapper.cls, self.attr):
+            return True
+
+        if not self.mapper.connected():
+            return True
+
+        if self.knowable_dirty and not self.is_dirty:
+            # wouldn't need to save
+            #print "Skip save:  {0}".format(self.attr)
+            return True
+
+        return False
 
     def Factory(self):
         """
@@ -81,6 +102,8 @@ class LineYoke(InputYoke):
     def Factory(self):
         self.widget = QtGui.QLineEdit()
         self.widget.editingFinished.connect(self.Save)
+        self.widget.textChanged.connect(lambda text: self.mark_dirty())
+        self.knowable_dirty = True
         self._baseAdoptWidget(self.widget)
         if attrReadonly(self.mapper.cls, self.attr):
             self.widget.setReadOnly(True)
@@ -91,12 +114,15 @@ class LineYoke(InputYoke):
         self._baseAdoptWidget(self.widget)
         if isinstance(self.widget, QtGui.QLineEdit):
             self.widget.editingFinished.connect(self.Save)
+            self.widget.textChanged.connect(lambda text: self.mark_dirty())
+            self.knowable_dirty = True
         if hasattr(self.widget, "setReadOnly") and attrReadonly(self.mapper.cls, self.attr):
             self.widget.setReadOnly(True)
 
     def Bind(self):
         if isinstance(self.widget, QtGui.QLineEdit):
             self.widget.setText(self.mapper.getObjectAttr(self.attr))
+            self.is_dirty = False
         elif isinstance(self.widget, QtGui.QComboBox):
             if self.widget.isEditable():
                 self.widget.setEditText(self.mapper.getObjectAttr(self.attr))
@@ -106,8 +132,9 @@ class LineYoke(InputYoke):
             raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         if isinstance(self.widget, QtGui.QLineEdit):
             self.mapper.setObjectAttr(self.attr,self.widget.text())
         elif isinstance(self.widget, QtGui.QComboBox):
@@ -135,6 +162,7 @@ class SelectionYoke(LineYoke):
 
     def Factory(self):
         self.widget = QtGui.QComboBox()
+        self.widget.currentIndexChanged.connect(lambda text: self.Save())
         self._baseAdoptWidget(self.widget)
         self._loadOptions()
         if attrReadonly(self.mapper.cls, self.attr):
@@ -145,6 +173,8 @@ class SelectionYoke(LineYoke):
         self.widget = widget
         self._baseAdoptWidget(self.widget)
         self._loadOptions()
+        if hasattr(self.widget, "currentIndexChanged"):
+            self.widget.currentIndexChanged.connect(lambda text: self.Save())
         if hasattr(self.widget, "setReadOnly") and attrReadonly(self.mapper.cls, self.attr):
             self.widget.setReadOnly(True)
 
@@ -186,8 +216,9 @@ class IntegerYoke(LineYoke):
         self.widget.setText(str(x))
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+ 
         t = self.widget.text()
         x = 0 if t in [None, ""] else int(t)
         self.mapper.setObjectAttr(self.attr,x)
@@ -216,8 +247,9 @@ class FloatingPointYoke(LineYoke):
         self.widget.setText(str(x))
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         t = self.widget.text()
         x = decimal.Decimal('0') if t in [None,""] else decimal.Decimal(t)
         self.mapper.setObjectAttr(self.attr,x)
@@ -250,8 +282,9 @@ class TextYoke(InputYoke):
             raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         if isinstance(self.widget, QtGui.QTextEdit) or isinstance(self.widget, QtGui.QPlainTextEdit):
             self.mapper.setObjectAttr(self.attr,self.widget.toPlainText())
         elif isinstance(self.widget, QtGui.QLineEdit):
@@ -284,8 +317,9 @@ class FormattedYoke(InputYoke):
             raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         if isinstance(self.widget, QtGui.QTextEdit):
             self.mapper.setObjectAttr(self.attr,self.widget.toHtml())
         else:
@@ -302,6 +336,8 @@ class DateYoke(LineYoke):
         self.widget = PBDateEdit()
         self._baseAdoptWidget(self.widget)
         self.widget.editingFinished.connect(self.Save)
+        self.widget.textChanged.connect(lambda text: self.mark_dirty())
+        self.knowable_dirty = True
         if hasattr(self.widget, "setReadOnly") and attrReadonly(self.mapper.cls, self.attr):
             self.widget.setReadOnly(True)
         return self.widget
@@ -311,10 +347,12 @@ class DateYoke(LineYoke):
         if d is not None:
             d = toQType(d)
         self.widget.setDate(d)
+        self.is_dirty = False
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         d = self.widget.date
         if d is None:
             self.mapper.setObjectAttr(self.attr,None)
@@ -351,8 +389,9 @@ class TimeYoke(LineYoke):
         self.widget.setTime(d)
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         d = self.widget.time()
         if d is None:
             self.mapper.setObjectAttr(self.attr,None)
@@ -380,8 +419,9 @@ class BooleanYoke(InputYoke):
         self.widget.setChecked(toQType(self.mapper.getObjectAttr(self.attr), bool))
 
     def Save(self):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         self.mapper.setObjectAttr(self.attr,fromQType(self.widget.isChecked()))
 
     def LabelStyle(self):
@@ -435,8 +475,9 @@ class BooleanRadioYoke(InputYoke):
             self.false_radio.setChecked(True)
 
     def Save(self, value=None):
-        if attrReadonly(self.mapper.cls, self.attr):
+        if self._save_dirty_blowout():
             return
+
         if value is None:
             if self.true_radio.isChecked():
                 value = True
