@@ -2,7 +2,7 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
@@ -157,7 +157,7 @@ class UserAttr(property):
         >>> jane.age
         0
     """
-    def __init__(self,atype,label,storage=None,readonly=False,whats_this=None):
+    def __init__(self, atype, label, storage=None, readonly=False, **kwargs):
         """
         The UserAttr property extends python 'property' class to provide a type and label and default storage.
         
@@ -167,6 +167,12 @@ class UserAttr(property):
          - if not specified, it is derived by turning label into a python safe name with leading underscores, etc.
          - storage can be specified as a dot qualified multi-identifier and the components will be resolved iteratively
         :param readonly: display this property as read-only in the interface
+
+        Possible arguments in kwargs include:
+            - whats_this
+            - yoke_specifier
+            - alignment
+            - empty_zero
         """
         property.__init__(self,self.fget,self.fset)
         self.atype = atype
@@ -176,11 +182,33 @@ class UserAttr(property):
             self.storage = "_UserAttr_" + re.sub("[^a-zA-Z0-9_]","_",label)
         self.label = label
         self.readonly = readonly
-        self.whats_this = whats_this
         self.__listeners = []
         self.__on_first_get = None
         self.__on_get = None
 
+        self.empty_zero = False
+
+        direct_assign_keys = ['whats_this', 'empty_zero']
+        prop_keys = ['yoke_specifier', 'alignment']
+
+        for x in prop_keys:
+            if kwargs.has_key(x):
+                setattr(self, '_'+x, kwargs[x])
+        for x in direct_assign_keys:
+            if kwargs.has_key(x):
+                setattr(self, x, kwargs[x])
+
+    @property
+    def alignment(self):
+        if self.__alignment is None:
+            if hasattr(self.atype, "alignment"):
+                return self.atype.alignment
+            else:
+                if self.atype in (int, float):
+                    return "right"
+        else:
+            return "left"
+
     @property
     def base_type(self):
         if hasattr(self.atype, "base_type"):
@@ -188,6 +216,12 @@ class UserAttr(property):
         else:
             return self.atype
 
+    def yoke_specifier(self):
+        if self._yoke_specifier is not None:
+            return self._yoke_specifier
+        else:
+            return None
+
     def _instrumentation(self,row):
         attrName = "_instrumentation_"+self.storage.replace('.','_')
         if not hasattr(row,attrName):
@@ -347,6 +381,10 @@ class AttrNumeric:
             v = decimal.Decimal(value)
             return v._rescale(-self.prec,'ROUND_HALF_UP')
 
+    @property
+    def alignment(self):
+        return "right"
+
     def yoke_specifier(self):
         if self.prec==0:
             return "int"
