@@ -2,12 +2,12 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
 from qtalchemy import *
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 
 # patterned after http://labs.qt.nokia.com/2007/06/06/lineedit-with-a-clear-button/
 
