@@ -28,7 +28,7 @@ class TableView(QtGui.QTableView, ViewBase):
     related concern of saving column geometry.
     """
     def __init__(self, parent=None, extensionId=None):
-        QtGui.QTableView.__init__(self,parent)
+        super(TableView, self).__init__(parent)
         self.use_edit_tab_semantics = False
         self.setProperty("ExtensionId", extensionId)
 
@@ -55,7 +55,7 @@ class TableView(QtGui.QTableView, ViewBase):
             # clobber the parameter to __init__ if specified non-None here
             self.setProperty("ExtensionId", extensionId)
 
-        QtGui.QTableView.setModel(self, model)
+        super(TableView, self).setModel(model)
         # hook up model resets to preserve selection across reloads
         self.model().modelAboutToBeReset.connect(self.preReset)
         self.model().modelReset.connect(self.postReset)
@@ -70,42 +70,41 @@ class TableView(QtGui.QTableView, ViewBase):
             cb = QtGui.QApplication.instance().clipboard()
             cb.setMimeData(modelMimeRectangle(self.model(), self.selectedIndexes()))
         else:
-            QtGui.QTableView.keyPressEvent(self,event)
+            super(TableView, self).keyPressEvent(event)
 
     def edit(self, index, trigger, event):
         # At this point this method is overridden strictly as a place to set the flag to initiate the 
         # semantics of moveCursor to skip read-only cells in tabbing.
-        inherited = QtGui.QTableView.edit(self, index, trigger, event)
+        inherited = super(TableView, self).edit(index, trigger, event)
         if inherited:
             self.use_edit_tab_semantics = True
         return inherited
 
     def moveCursor(self, cursorAction, modifiers):
-        if self.use_edit_tab_semantics == True:
-            # Skip read-only cells.
-            # We max out at iterating through the equivalent of 3 full rows 
-            # because that probably indicates an unexpected situation.
-            cell_max = self.model().columnCount(None) * 3
-            iterations = 0
-            if cursorAction == QtGui.QAbstractItemView.MoveNext:
-                index = self.currentIndex()
-                model = self.model()
-                while iterations < cell_max:
-                    iterations += 1
-                    candidate = self.nextIndex(index)
-                    if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
-                        return candidate
-                    index = candidate
-            elif cursorAction == QtGui.QAbstractItemView.MovePrevious:
-                index = self.currentIndex()
-                model = self.model()
-                while iterations < cell_max:
-                    iterations += 1
-                    candidate = self.prevIndex(index)
-                    if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
-                        return candidate
-                    index = candidate
-        return QtGui.QTableView.moveCursor(self,cursorAction,modifiers)
+        if self.use_edit_tab_semantics == True and cursorAction in [QtGui.QAbstractItemView.MoveNext,  QtGui.QAbstractItemView.MovePrevious]:
+            index = self.currentIndex()
+            model = self.model()
+            if model.columnCount(index.parent()) > 0 and model.rowCount(index.parent()) > 0:
+                # Skip read-only cells.
+                # We max out at iterating through the equivalent of 3 full rows 
+                # because that probably indicates an unexpected situation.
+                cell_max = self.model().columnCount(None) * 3
+                iterations = 0
+                if cursorAction == QtGui.QAbstractItemView.MoveNext:
+                    while iterations < cell_max:
+                        iterations += 1
+                        candidate = self.nextIndex(index)
+                        if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
+                            return candidate
+                        index = candidate
+                elif cursorAction == QtGui.QAbstractItemView.MovePrevious:
+                    while iterations < cell_max:
+                        iterations += 1
+                        candidate = self.prevIndex(index)
+                        if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
+                            return candidate
+                        index = candidate
+        return super(TableView, self).moveCursor(cursorAction,modifiers)
 
     def preReset(self):
         index = self.selectionModel().currentIndex()
